==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebColumnVisibilityChangingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata } from "./WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata";
import { WebColumnVisibilityChangingEventArgsDescription } from "./WebColumnVisibilityChangingEventArgsDescription";
/**
 * @hidden
 */
var WebColumnVisibilityChangingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnVisibilityChangingEventArgsDescriptionMetadata, _super);
    function WebColumnVisibilityChangingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.b = function (a) {
        if (WebColumnVisibilityChangingEventArgsDescriptionMetadata.a == null) {
            WebColumnVisibilityChangingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnVisibilityChangingEventArgsDescriptionMetadata.c(WebColumnVisibilityChangingEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebColumnVisibilityChangingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebColumnVisibilityChangingEventArgsDescriptionMetadata.a);
        WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.d(a);
    };
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnVisibilityChangingEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebColumnVisibilityChangingEventArgsDetail");
    };
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.d = function (a) {
        WebColumnVisibilityChangingEventArgsDescriptionMetadata.b(a);
        a.aa("WebColumnVisibilityChangingEventArgs", function () { return new WebColumnVisibilityChangingEventArgsDescription(); });
        a.z("WebColumnVisibilityChangingEventArgs", WebColumnVisibilityChangingEventArgsDescriptionMetadata.a);
    };
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.$t = markType(WebColumnVisibilityChangingEventArgsDescriptionMetadata, 'WebColumnVisibilityChangingEventArgsDescriptionMetadata');
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.a = null;
    return WebColumnVisibilityChangingEventArgsDescriptionMetadata;
}(Base));
export { WebColumnVisibilityChangingEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebColumnVisibilityChangingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata } from "./WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata";
import { WebColumnVisibilityChangingEventArgsDescription } from "./WebColumnVisibilityChangingEventArgsDescription";
/**
 * @hidden
 */
var WebColumnVisibilityChangingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnVisibilityChangingEventArgsDescriptionMetadata, _super);
    function WebColumnVisibilityChangingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.b = function (a) {
        if (WebColumnVisibilityChangingEventArgsDescriptionMetadata.a == null) {
            WebColumnVisibilityChangingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnVisibilityChangingEventArgsDescriptionMetadata.c(WebColumnVisibilityChangingEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebColumnVisibilityChangingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebColumnVisibilityChangingEventArgsDescriptionMetadata.a);
        WebColumnVisibilityChangingEventArgsDetailDescriptionMetadata.d(a);
    };
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnVisibilityChangingEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebColumnVisibilityChangingEventArgsDetail");
    };
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.d = function (a) {
        WebColumnVisibilityChangingEventArgsDescriptionMetadata.b(a);
        a.ac("WebColumnVisibilityChangingEventArgs", function () { return new WebColumnVisibilityChangingEventArgsDescription(); });
        a.ab("WebColumnVisibilityChangingEventArgs", WebColumnVisibilityChangingEventArgsDescriptionMetadata.a);
    };
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.$t = markType(WebColumnVisibilityChangingEventArgsDescriptionMetadata, 'WebColumnVisibilityChangingEventArgsDescriptionMetadata');
    WebColumnVisibilityChangingEventArgsDescriptionMetadata.a = null;
    return WebColumnVisibilityChangingEventArgsDescriptionMetadata;
}(Base));
export { WebColumnVisibilityChangingEventArgsDescriptionMetadata };
